==> haskell-http-common-0.8.3.4-236-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-DgNVgiuZqku5S5x2BhBi1
key:                  http-common-0.8.3.4-DgNVgiuZqku5S5x2BhBi1
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  45a645d411d6e014a1531ec2afc66075
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-DgNVgiuZqku5S5x2BhBi1
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb
    blaze-builder-0.4.4-4SWbbNyka061tgppH7HvSN bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5qBt9JHinkAC9eq4HZukmL directory-1.3.7.1
    mtl-2.2.2 network-3.1.4.0-KmVGd8MQrab5lGMy9eMLcZ
    random-1.2.1.3-AItr1WcsEfaHebdgTnBQBQ text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.3.4-237-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-EFpiwENlkw4H59d8JVVHb3
key:                  http-common-0.8.3.4-EFpiwENlkw4H59d8JVVHb3
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  21e0403af082583dc4d0c8297bfc0b2e
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-EFpiwENlkw4H59d8JVVHb3
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-LWeAHO93Hqh8w1c79M45du
    blaze-builder-0.4.4-9Y3q4YsfSJE9aDeePNxCbC bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6fVgEt7vrFc1sDHTeWeWXd directory-1.3.7.1
    mtl-2.2.2 network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX
    random-1.2.1.3-AojK1F3ExhxDorHTlNe3sA text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
